@@ -1,12 +1,16 @@
 # No predictor -------------------------------------------------------------------------------
 
 test_that("it plots the empty model as a horizontal line when outcome is on Y, two axis plots", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
     expect_doppelganger("[gf_point] null mod., y on Y")
 })
 
 test_that("it plots the empty model as a vertical line when outcome is on Y, one axis plot", {
+  testthat::skip_on_ci()
+
   # I know that the plot has two axes, but I only specify one, that's why "one" axis plot
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] null mod., y on Y")
@@ -30,7 +34,7 @@ test_that("it plots the empty model as a vertical line when outcome is on Y, one
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
     expect_doppelganger(snap_name("gf_boxplot", " -- 2"))
 
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
 
   gf_violin(later_anxiety ~ 1, data = er) %>%
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
@@ -38,15 +42,18 @@ test_that("it plots the empty model as a vertical line when outcome is on Y, one
 })
 
 test_that("it plots the empty model as a horizontal line when outcome is on X, two axis plot", {
+  testthat::skip_on_ci()
   gf_point(base_anxiety ~ later_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
     expect_doppelganger("[gf_point] null mod., y on X")
 })
 
 test_that("it plots the empty model as a vertical line when outcome is on X, one axis plot", {
+  testthat::skip_on_ci()
+
   # I know that the plot has two axes, but I only specify one, that's why "one" axis plot
   snap_name <- function(plot_name, suffix = "") {
-    glue("[{plot_name}] mull mod., y on X{suffix}")
+    glue("[{plot_name}] null mod., y on X{suffix}")
   }
 
   plot_args <- list(gformula = ~later_anxiety, color = ~condition, data = er)
@@ -64,7 +71,7 @@ test_that("it plots the empty model as a vertical line when outcome is on X, one
     expect_doppelganger(snap_name("gf_boxplot"))
 
 
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
 
   gf_violin(1 ~ later_anxiety, data = er) %>%
     gf_model(lm(later_anxiety ~ NULL, data = er)) %>%
@@ -87,7 +94,8 @@ test_that("it plots the empty model as a vertical line when outcome is on X, one
 # Single predictor, on axis, categorical ------------------------------------------------------
 
 test_that("it plots 1 predictor (on axis, categorical) models as lines at means, outcome on Y", {
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
+  testthat::skip_on_ci()
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., y on Y{suffix}")
@@ -103,6 +111,8 @@ test_that("it plots 1 predictor (on axis, categorical) models as lines at means,
 })
 
 test_that("it plots 1 predictor (on axis, categorical) models as lines at means, outcome on X", {
+  testthat::skip_on_ci()
+
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., y on X{suffix}")
   }
@@ -120,7 +130,8 @@ test_that("it plots 1 predictor (on axis, categorical) models as lines at means,
 # Single predictor, on aesthetic, categorical -------------------------------------------------
 
 test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, outcome on Y", {
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
+  testthat::skip_on_ci()
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., y on Y, pred. on color")
@@ -146,7 +157,8 @@ test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, o
 })
 
 test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, outcome on X", {
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
+  testthat::skip_on_ci()
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., y on X, pred. on color")
@@ -175,7 +187,8 @@ test_that("it plots 1 predictor (on aesthetic, cat.) models as lines at means, o
 # Single predictor, on facet, categorical -----------------------------------------------------
 
 test_that("it plots 1 predictor (on facet, compact cat.) models as lines at means, outcome on Y", {
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
+  testthat::skip_on_ci()
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., y on Y, pred. on facet")
@@ -212,7 +225,8 @@ test_that("it plots 1 predictor (on facet, compact cat.) models as lines at mean
 })
 
 test_that("it plots 1 predictor (on facet, compact cat.) models as lines at means, outcome on X", {
-  testthat::skip_if(Sys.getenv("CI") == "true", "Skipping these tests on GitHub Actions.")
+  testthat::skip_on_ci()
+  testthat::skip_on_ci()
 
   snap_name <- function(plot_name, suffix = "") {
     glue("[{plot_name}] cond. mod., y on X, pred. on facet")
@@ -242,6 +256,8 @@ test_that("it plots 1 predictor (on facet, compact cat.) models as lines at mean
 # Single predictor, on axis, continuous -------------------------------------------------------
 
 test_that("it plots 1 predictor (on axis, cont.) models as a fit line", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety, data = er)) %>%
     expect_doppelganger("[gf_point] anx. mod., y on Y")
@@ -255,6 +271,8 @@ test_that("it plots 1 predictor (on axis, cont.) models as a fit line", {
 # Single predictor, on aesthetic, continuous --------------------------------------------------
 
 test_that("it splits continuous aesthetic predictors at -+1 SD and mean", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ condition, color = ~base_anxiety, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety, data = er)) %>%
     expect_doppelganger("[gf_point] anx. mod., pred. on color, y on Y")
@@ -268,36 +286,48 @@ test_that("it splits continuous aesthetic predictors at -+1 SD and mean", {
 # Two predictors, on axis and aesthetic -------------------------------------------------------
 
 test_that("it plots main effects models (cat. + cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ provider, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ provider + condition, data = er)) %>%
     expect_doppelganger("[gf_point] floating 'parallel' hashes in two colors")
 })
 
 test_that("it plots main effects models (quant. + cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety + condition, data = er)) %>%
     expect_doppelganger("[gf_point] parallel lines in 2 colors")
 })
 
 test_that("it plots main effects models (cat. + quant.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ condition, color = ~base_anxiety, data = er) %>%
     gf_model(lm(later_anxiety ~ condition + base_anxiety, data = er)) %>%
     expect_doppelganger("[gf_point] parallel hashes in 3 colors (M, +-SD)")
 })
 
 test_that("it plots main effect models (quant. + quant.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~base_depression, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety + base_depression, data = er)) %>%
     expect_doppelganger("[gf_point] parallel lines in 3 colors (M, +-SD)")
 })
 
 test_that("it plots interactive models (cat. * cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ provider, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ provider * condition, data = er)) %>%
     expect_doppelganger("[gf_point] diverging hashes in 2 colors")
 })
 
 test_that("it plots interactive models (quant. * cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety * condition, data = er)) %>%
     expect_doppelganger("[gf_point] diverging lines in 2 colors")
@@ -308,12 +338,16 @@ test_that("it plots interactive models (quant. * cat.)", {
 })
 
 test_that("it plots interactive models (cat. * quant.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ condition, color = ~base_anxiety, data = er) %>%
     gf_model(lm(later_anxiety ~ condition * base_anxiety, data = er)) %>%
     expect_doppelganger("[gf_point] non-parallel hashes in 3 colors (M, +-SD)")
 })
 
 test_that("it plots interactive models (quant. * quant.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~base_depression, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety * base_depression, data = er)) %>%
     expect_doppelganger("[gf_point] crossing lines in 2 colors")
@@ -323,24 +357,32 @@ test_that("it plots interactive models (quant. * quant.)", {
 # Two predictors, on axis and facet -----------------------------------------------------------
 
 test_that("it plots main effect models across facets (cat. + cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ provider | condition, data = er) %>%
     gf_model(lm(later_anxiety ~ provider + condition, data = er)) %>%
     expect_doppelganger("[gf_point] hashes at an offset across facets")
 })
 
 test_that("it plots main effect models across facets (quant. + cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety | condition, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety + condition, data = er)) %>%
     expect_doppelganger("[gf_point] parallel lines in different facets")
 })
 
 test_that("it plots interactive models across facets (cat. * cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ provider | condition, data = er) %>%
     gf_model(lm(later_anxiety ~ provider * condition, data = er)) %>%
     expect_doppelganger("[gf_point] hash patterns across facets")
 })
 
 test_that("it plots interactive models across facets (quant. * cat.)", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety | condition, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety * condition, data = er)) %>%
     expect_doppelganger("[gf_point] diverging lines in facets")
@@ -360,30 +402,40 @@ test_that("it plots interactive models across facets (quant. * cat.)", {
 # Mappings ------------------------------------------------------------------------------------
 
 test_that("it respects static aesthetic choices", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety, data = er), color = "blue") %>%
     expect_doppelganger("[gf_point] model line is blue")
 })
 
 test_that("it un-maps dynamic aesthetics from underlying layers that are not in the model", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, shape = ~provider, data = er) %>%
     gf_model(lm(later_anxiety ~ base_anxiety, data = er)) %>%
     expect_doppelganger("[gf_point] anx. mod., y on Y, with color & shape")
 })
 
 test_that("it will translate color arguments if applicable (e.g. fill to color)", {
+  testthat::skip_on_ci()
+
   gf_boxplot(later_anxiety ~ provider, fill = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ condition, data = er)) %>%
     expect_doppelganger("[gf_point] cond. mod., y on Y, with color")
 })
 
 test_that("it can use aesthetics other than color... just checking", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, shape = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ condition, data = er)) %>%
     expect_doppelganger("[gf_point] cond. mod., y on Y, pred. on shape")
 })
 
 test_that("it allows mapping new aesthetics", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(lm(later_anxiety ~ condition, data = er), linetype = ~condition) %>%
     expect_doppelganger("[gf_point] cond. mod., y on Y, pred. on color, linetype")
@@ -394,6 +446,8 @@ test_that("it allows mapping new aesthetics", {
 # Alternate specification ---------------------------------------------------------------------
 
 test_that("you can pass it a formula instead of an `lm()` object", {
+  testthat::skip_on_ci()
+
   gf_point(later_anxiety ~ base_anxiety, color = ~condition, data = er) %>%
     gf_model(later_anxiety ~ condition) %>%
     expect_doppelganger("match to lm() version")
@@ -403,6 +457,8 @@ test_that("you can pass it a formula instead of an `lm()` object", {
 # Other tests ---------------------------------------------------------------------------------
 
 test_that("it treats boolean and character predictors like factors", {
+  testthat::skip_on_ci()
+
   new_er <- er %>%
     mutate(base_anxiety_high = base_anxiety > 5)
 
